@@ -1,3 +1,4 @@
+from functools import partial
 import logging
 
 from django.conf import settings
@@ -8,13 +9,30 @@ from django.db.models.signals import post_save
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
-from markitup.fields import MarkupField, render_func
+from markitup.fields import MarkupField
 
-from wafer.menu import MenuError, refresh_menu_cache
+from wafer.menu import refresh_menu_cache
 
 logger = logging.getLogger(__name__)
 
 
+class PageMarkupField(MarkupField):
+    """MarkupField that uses our own render function"""
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        dotted_path, kwargs = settings.WAFER_PAGE_MARKITUP_FILTER
+        module, func = dotted_path.rsplit('.', 1)
+        func = getattr(__import__(module, {}, {}, [func]), func)
+        self.render_func = partial(func, **kwargs)
+
+    def pre_save(self, model_instance, add):
+        value = super().pre_save(model_instance, add)
+        rendered = self.render_func(value)
+        rendered_field_name = getattr(model_instance, self.attname).rendered_field_name
+        setattr(model_instance, rendered_field_name, rendered)
+        return value
+
+
 class File(models.Model):
     """A file for use in page markup."""
     name = models.CharField(max_length=255)
@@ -31,7 +49,7 @@ class Page(models.Model):
     slug = models.SlugField(help_text=_("Last component of the page URL"))
     parent = models.ForeignKey(
         'self', null=True, blank=True, on_delete=models.CASCADE, related_name="children")
-    content = MarkupField(
+    content = PageMarkupField(
         help_text=_("Markdown contents for the page."))
     include_in_menu = models.BooleanField(
         help_text=_("Whether to include in menus."),
@@ -92,7 +110,8 @@ class Page(models.Model):
         cache_key = self._cache_key()
         rendered = cache.get(cache_key)
         if rendered is None:
-            rendered = render_func(self.content.raw)
+            content_field = self._meta.get_field('content')
+            rendered = content_field.render_func(self.content.raw)
             # Should reset the database copy, but this is enough for
             # now
             cache.set(cache_key, rendered, self.cache_time)
@@ -139,7 +158,7 @@ class Page(models.Model):
                     })
             keys.append(parent.pk)
             parent = parent.parent
-        return super(Page, self).clean()
+        return super().clean()
 
     def validate_unique(self, exclude=None):
         existing = Page.objects.filter(slug=self.slug, parent=self.parent)
@@ -153,11 +172,11 @@ class Page(models.Model):
                         _("Duplicate parent/slug combination."),
                     ],
                 })
-        return super(Page, self).validate_unique(exclude)
+        return super().validate_unique(exclude)
 
     def save(self, *args, **kwargs):
         """Ensure we invalidate the cache after saving"""
-        super(Page, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
         self.invalidate_cache()
 
 
