@@ -1,7 +1,11 @@
+from uuid import UUID
+
+from django.core.cache import cache
 from django.core.exceptions import ValidationError
 from django.db import models
 from django.db.models.signals import post_save, post_delete
 from django.urls import reverse
+from django.utils.crypto import salted_hmac
 from django.utils.translation import ugettext_lazy as _
 from django.utils.timezone import localtime
 
@@ -297,6 +301,13 @@ class ScheduleItem(models.Model):
             return self.page.get_absolute_url()
         return None
 
+    def get_slug(self):
+        if self.talk:
+            return self.talk.slug
+        elif self.page:
+            return self.page.slug
+        return None
+
     def get_details(self):
         return self.get_desc()
 
@@ -343,6 +354,29 @@ class ScheduleItem(models.Model):
         duration = self.get_duration()
         return int(duration['hours'] * 60 + duration['minutes'])
 
+    @property
+    def guid(self):
+        """Return a GUID for the ScheduleItem (for frab xml)
+
+        We return static GUIDs across re-scheduling, when possible.
+        """
+        if self.talk:
+            id_ = 'talk:' + str(self.talk.pk)
+        elif self.page and self.page.scheduleitem_set.count() == 1:
+            id_ = 'page:' + str(self.page.pk)
+        else:
+            id_ = 'schedule_item:' + str(self.pk)
+        hmac = salted_hmac('wafer-event-uuid', id_)
+        return UUID(bytes=hmac.digest()[:16])
+
+
+def get_schedule_version():
+    """Return the current schedule version as a string"""
+    version = cache.get('wafer_schedule_version')
+    if not version:
+        version = update_schedule_version()
+    return version
+
 
 def invalidate_check_schedule(*args, **kw):
     sender = kw.pop('sender', None)
@@ -365,7 +399,7 @@ def update_schedule_items(*args, **kw):
         return
     for item in slot.scheduleitem_set.all():
         item.save(update_fields=['last_updated'])
-    # We also need to update the next slot, in case we changed it's
+    # We also need to update the next slot, in case we changed its
     # times as well
     next_slot = slot.slot_set.all()
     if next_slot.count():
@@ -375,15 +409,24 @@ def update_schedule_items(*args, **kw):
             item.save(update_fields=['last_updated'])
 
 
-post_save.connect(invalidate_check_schedule, sender=ScheduleBlock)
-post_save.connect(invalidate_check_schedule, sender=Venue)
-post_save.connect(invalidate_check_schedule, sender=Slot)
-post_save.connect(invalidate_check_schedule, sender=ScheduleItem)
+def update_schedule_version(*args, **kwargs):
+    """Store the schedule version in the Django cache.
 
-post_delete.connect(invalidate_check_schedule, sender=ScheduleBlock)
-post_delete.connect(invalidate_check_schedule, sender=Venue)
-post_delete.connect(invalidate_check_schedule, sender=Slot)
-post_delete.connect(invalidate_check_schedule, sender=ScheduleItem)
+    The version is used to allow clients to perform conditional HTTP requests
+    on the schedule.
+
+    We don't just rely on max(ScheduleItem.updated_at) as that misses
+    deletions.
+    """
+    version = localtime().isoformat()
+    cache.set('wafer_schedule_version', version, timeout=None)
+    return version
+
+
+for sender in (ScheduleBlock, Venue, Slot, ScheduleItem):
+    for receiver in (invalidate_check_schedule, update_schedule_version):
+        post_save.connect(receiver, sender=sender)
+        post_delete.connect(receiver, sender=sender)
 
 # We also hook up calls from Page and Talk, so
 # changes to those reflect in the schedule immediately
