@@ -164,7 +164,8 @@ class Talk(models.Model):
         Track, verbose_name=_("track"), null=True, blank=True, on_delete=models.SET_NULL)
 
     LANGUAGES = settings.WAFER_TALK_LANGUAGES
-    DEFAULT_LANGUAGE = LANGUAGES and LANGUAGES[0][0]
+    # DEFAULT_LANGUAGE should be None if WAFER_TALK_LANGUAGES is empty
+    DEFAULT_LANGUAGE = LANGUAGES[0][0] if LANGUAGES else None
     language = models.CharField(
         verbose_name=_("language"),
         max_length=5,
@@ -309,7 +310,7 @@ class Talk(models.Model):
     @property
     def review_score(self):
         # Overridden in admin, to allow sorting
-        reviews = [review.avg_score for review in self.reviews.all() if review.avg_score]
+        reviews = [review.avg_score for review in self.reviews.all() if review.avg_score is not None]
         if not reviews:
             return None
         return sum(reviews) / len(reviews)
